@@ -42,7 +42,7 @@ class DeskbarHistory (gtk.ListStore) :
     
     __gsignals__ = {
         "cleared" :        (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, []),
-        "action-added" :   (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, [str, gobject.TYPE_PYOBJECT]),
+        "action-added" :   (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, [str, gobject.TYPE_PYOBJECT]), 
     }
     __instance = None
     (COL_TIME, COL_TEXT, COL_ACTION) = range(3)
@@ -115,7 +115,6 @@ class DeskbarHistory (gtk.ListStore) :
         """
         Load history
         """
-        new_history = []
         try:
             saved_history = cPickle.load(file(HISTORY_FILE))
             
@@ -136,7 +135,6 @@ class DeskbarHistory (gtk.ListStore) :
             # The history file is corrupted
             LOGGER.error("Could not restore history")
             LOGGER.exception(e)
-            pass
         
         if len(self) == 0:
             self.append(0, "", EmptyHistoryAction())
@@ -154,7 +152,6 @@ class DeskbarHistory (gtk.ListStore) :
             cPickle.dump(save, file(HISTORY_FILE, 'w'), cPickle.HIGHEST_PROTOCOL)
         except Exception, msg:
             LOGGER.error('History.save:%s', msg)
-        pass
     
     def append (self, timestamp, text, action):
         """
@@ -190,11 +187,11 @@ class DeskbarHistory (gtk.ListStore) :
         for idx, val in enumerate(self):
             htime, htext, haction = val
             if isinstance(haction, EmptyHistoryAction):
-                self.remove (self.get_iter_from_string (str(idx)))
+                self.remove_index (idx)
                 continue
                 
             if (action.get_hash() == haction.get_hash() and action.__class__.__name__ == haction.__class__.__name__):
-                self.remove (self.get_iter_from_string (str(idx)))
+                self.remove_index (idx)
                 break
                 
         timestamp = time.strftime("%Y-%m-%d %H:%M:%S", time.gmtime())
@@ -203,11 +200,22 @@ class DeskbarHistory (gtk.ListStore) :
 
         self.reset()
         self.save()
+        
+    def remove(self, aiter):
+        gtk.ListStore.remove(self, aiter)
+        if len(self) == 0:
+            self.clear()
+        
+    def remove_index(self, index):
+        self.remove (self.get_iter_from_string (str(index)))
+    
+    def remove_and_save(self, aiter):
+        self.remove(aiter)
+        self.save()
     
     def __remove_too_many(self):
         while len(self) > self.__max_history_items:
-            last = self.get_iter_from_string (str(len(self) - 1))
-            self.remove (last)
+            self.remove_index (len(self) - 1)
     
     def up(self):
         """
