@@ -5,15 +5,17 @@ from htmlentitydefs import name2codepoint
 from os.path import *
 import cgi
 import deskbar
-import deskbar.core.gnomedesktop
+import gnomedesktop
 import gnome.ui
 import gnomevfs
 import gobject
 import gtk
 import gtk.gdk
+import locale
 import logging
 import os
 import re
+import base64
 
 LOGGER = logging.getLogger(__name__)
 
@@ -78,7 +80,7 @@ def get_xdg_data_dirs():
 
 def load_icon_for_desktop_icon(icon):
     if icon != None:
-        icon = deskbar.core.gnomedesktop.find_icon(ICON_THEME, icon, deskbar.ICON_HEIGHT, 0)
+        icon = gnomedesktop.find_icon(ICON_THEME, icon, deskbar.ICON_HEIGHT, 0)
         if icon != None:
             return load_icon(icon)
         
@@ -124,6 +126,33 @@ def load_icon(icon, width=deskbar.ICON_HEIGHT, height=deskbar.ICON_HEIGHT):
 def load_icon_from_icon_theme(iconname, size):
     return ICON_THEME.load_icon(iconname, size, gtk.ICON_LOOKUP_USE_BUILTIN)
 
+def load_base64_icon (base64_str):
+    """
+    Load a base64 encoded image as a C{gtk.gdk.Pixbuf}.
+    
+    @param base64_str: a C{string} with a base64 encoded image
+    @return: A C{gtk.gdk.Pixbuf} or a fallback icon in case there are errors
+        parsing C{base64_str}.
+    """
+    loader = gtk.gdk.PixbufLoader()
+    
+    try:
+        try:
+            loader.set_size(deskbar.ICON_HEIGHT, deskbar.ICON_HEIGHT)
+            loader.write(base64.b64decode(base64_str))
+        except Exception, e:
+            LOGGER.warning ("Failed to read base64 encoded image: %s" % e)
+        except gobject.GError, ee:
+            LOGGER.warning ("Failed to read base64 encoded image: %s" % ee)
+    finally:
+        loader.close()
+        
+    pixbuf = loader.get_pixbuf()
+    if pixbuf :
+        return pixbuf
+    
+    return _get_fall_back_icon()
+
 def _get_fall_back_icon():
     """
     @return: stock_unknown icon or C{None}
@@ -208,3 +237,15 @@ def get_proxy():
         return proxies
     else:
         return None
+    
+def get_locale_lang():
+    """
+    @returns language code corresponding to RFC 1766 of currently used locale
+    or None when the code is unknown
+    """
+    try:
+        localelang = locale.getlocale()[0]
+    except ValueError:
+        return None
+    
+    return localelang
